@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: trifecta
 version: 1.5.2
-id: trifecta-1.5.2-b68fb8cfa11dfffb43c9703268ef863d
-key: trife_6xkbRG9MGCX2Cg1XZzmDzU
+id: trifecta-1.5.2-96179b3dc56b0523b4210016cc24d8aa
+key: trife_867UHYR4huK1wToRS1hYJ7
 license: BSD3
 copyright: Copyright (C) 2010-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
-hs-libraries: HStrifecta-1.5.2-6xkbRG9MGCX2Cg1XZzmDzU
+hs-libraries: HStrifecta-1.5.2-867UHYR4huK1wToRS1hYJ7
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
@@ -46,7 +46,7 @@ depends:
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
     lens-4.13.2.1-7da1232efa9fbb46f4651315f7427146
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    parsers-0.12.3-8e59be6b96cea7c948bd2a9ce2f51dbc
+    parsers-0.12.3-39fdea4c999d2dce5f1305b594de4161
     profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
     reducers-3.12.1-9c0679f8e3a7104b42907174b9bc86fd
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
